PyTorch scaling test
====================

.. include:: ../../../tutorials/distributed-ml/torch-scaling-test/README.md
   :parser: myst_parser.sphinx_
   :end-before: Example of scalability plot generated by


Example of scalability plot generated by ``itwinai scalability-report``:


.. image:: ../../../tutorials/distributed-ml/torch-scaling-test/img/report.png


Configuration files
-------------------


base.yaml
+++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/config/base.yaml
   :language: yaml


ddp.yaml
++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/config/ddp.yaml
   :language: yaml


deepspeed.yaml
++++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/config/deepspeed.yaml
   :language: yaml


horovod.yaml
++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/config/horovod.yaml
   :language: yaml



Training scripts and utils
--------------------------


ddp_trainer.py
++++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/ddp_trainer.py
   :language: python


deepspeed_trainer.py
++++++++++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/deepspeed_trainer.py
   :language: python


horovod_trainer.py
++++++++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/horovod_trainer.py
   :language: python


itwinai_trainer.py
++++++++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/itwinai_trainer.py
   :language: python


utils.py
++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/utils.py
   :language: python


runall.sh
+++++++++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test//runall.sh
   :language: bash


scaling-test.sh
+++++++++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/scaling-test.sh
   :language: bash


slurm.sh
+++++++++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-scaling-test/slurm.sh
   :language: bash

